==> galeon_1.3.15.orig.tar.gz: galeon-1.3.15/embed/galeon-embed-prefs.h <==
#define CONF_MOUSE_WHEEL_NOKEY_ACTION "/apps/galeon/UI/Mouse/wheel_nokey_action"
#define CONF_MOUSE_WHEEL_NOKEY_DEF_STEP "/apps/galeon/UI/Mouse/wheel_nokey_default_step"
#define CONF_MOUSE_WHEEL_NOKEY_STEP "/apps/galeon/UI/Mouse/wheel_nokey_step"
#define CONF_NETWORK_SOCKS_PROXY_VERSION "/apps/galeon/Advanced/Network/socks_proxy_version"
#define CONF_NETWORK_PROXY_KA "/apps/galeon/Advanced/Network/proxy_keepalive"
#define CONF_NETWORK_DISK_CACHE "/apps/galeon/Advanced/Network/disk_cache_size"
#define CONF_NETWORK_CACHE_COMPARE "/apps/galeon/Advanced/Network/cache_compare"
#define CONF_NETWORK_USER_AGENT "/apps/galeon/Advanced/Network/user_agent"
#define CONF_NETWORK_HTTP_VERSION "/apps/galeon/Advanced/Network/http_version"

#define CONF_RENDERING_FONT "/apps/galeon/Rendering/font"
#define CONF_RENDERING_FONT_VAR_SIZE "/apps/galeon/Rendering/font_variable_size"
#define CONF_RENDERING_FONT_FIXED_SIZE "/apps/galeon/Rendering/font_monospace_size"
#define CONF_RENDERING_FONT_MIN_SIZE "/apps/galeon/Rendering/font_minimum_size"

#define CONF_RENDERING_LANGUAGE "/apps/galeon/Rendering/Language/lang"
#define CONF_RENDERING_USE_OWN_COLORS "/apps/galeon/Rendering/FontsColors/use_own_colors"
#define CONF_RENDERING_USE_SYSTEM_COLORS "/apps/galeon/Rendering/FontsColors/use_system_colors"
#define CONF_RENDERING_USE_OWN_FONTS "/apps/galeon/Rendering/FontsColors/use_own_fonts"
#define CONF_RENDERING_BG_COLOR "/apps/galeon/Rendering/FontsColors/background_color"
#define CONF_RENDERING_TEXT_COLOR "/apps/galeon/Rendering/FontsColors/text_color"
#define CONF_RENDERING_VISITED_LINKS "/apps/galeon/Rendering/FontsColors/visited_link_color"
#define CONF_RENDERING_UNVISITED_LINKS "/apps/galeon/Rendering/FontsColors/unvisited_link_color"
#define CONF_RENDERING_UNDERLINE_LINKS "/apps/galeon/Rendering/FontsColors/underline_links"
#define CONF_FILTERING_ALLOW_POPUPS "/apps/galeon/Advanced/Filtering/allow_popups"
#define CONF_FILTERING_IMAGE_LOADING_TYPE "/apps/galeon/Advanced/Filtering/image_loading_type"
#define CONF_FILTERING_ANIMATE_TYPE "/apps/galeon/Advanced/Filtering/animate_type"
#define CONF_FILTERING_JAVA_ENABLED "/apps/galeon/Advanced/Filtering/java_enabled"
#define CONF_FILTERING_JAVASCRIPT_ENABLED "/apps/galeon/Advanced/Filtering/javascript_enabled"
#define CONF_PERSISTENT_COOKIES_BEHAVIOR "/apps/galeon/Advanced/Persistent/cookie_behavior"
#define CONF_PERSISTENT_COOKIE_WARN "/apps/galeon/Advanced/Persistent/cookie_warn"
#define CONF_PERSISTENT_COOKIE_LIFETIME "/apps/galeon/Advanced/Persistent/cookie_lifetime"
#define CONF_PERSISTENT_PASSWORDS_SAVE "/apps/galeon/Advanced/Persistent/passwords_save"
#define CONF_LANGUAGE_AUTODETECT_CHARSET "/apps/galeon/Rendering/Language/autodetect_charset"
#define CONF_LANGUAGE_DEFAULT_CHARSET "/apps/galeon/Rendering/Language/default_charset"
#define CONF_RENDERING_DEFAULT_FONT "/apps/galeon/Rendering/FontsColors/default_font"
#define CONF_FILTERING_DEFAULT_STATUSBAR "/apps/galeon/Advanced/Filtering/default_allow_statusbar"

/* These are defined gnome wide now */
#define CONF_NETWORK_PROXY_MODE "/system/proxy/mode"
#define CONF_NETWORK_HTTP_PROXY "/system/http_proxy/host"
#define CONF_NETWORK_SSL_PROXY "/system/proxy/secure_host"
#define CONF_NETWORK_FTP_PROXY "/system/proxy/ftp_host"
#define CONF_NETWORK_SOCKS_PROXY "/system/proxy/socks_host"
#define CONF_NETWORK_HTTP_PROXY_PORT "/system/http_proxy/port"
#define CONF_NETWORK_SSL_PROXY_PORT "/system/proxy/secure_port"
#define CONF_NETWORK_FTP_PROXY_PORT "/system/proxy/ftp_port"
#define CONF_NETWORK_SOCKS_PROXY_PORT "/system/proxy/socks_port"
#define CONF_NETWORK_PROXY_AUTO_URL "/system/proxy/autoconfig_url"
#define CONF_NETWORK_PROXY_IGNORE_HOSTS "/system/http_proxy/ignore_hosts"

==> galeon_2.0.6.orig.tar.gz: galeon-2.0.6/embed/galeon-embed-prefs.h <==
#define CONF_MOUSE_WHEEL_NOKEY_ACTION "/apps/galeon/UI/Mouse/wheel_nokey_action"
#define CONF_MOUSE_WHEEL_NOKEY_DEF_STEP "/apps/galeon/UI/Mouse/wheel_nokey_default_step"
#define CONF_MOUSE_WHEEL_NOKEY_STEP "/apps/galeon/UI/Mouse/wheel_nokey_step"
#define CONF_NETWORK_SOCKS_PROXY_VERSION "/apps/galeon/Advanced/Network/socks_proxy_version"
#define CONF_NETWORK_PROXY_KA "/apps/galeon/Advanced/Network/proxy_keepalive"
#define CONF_NETWORK_DISK_CACHE "/apps/galeon/Advanced/Network/disk_cache_size"
#define CONF_NETWORK_CACHE_COMPARE "/apps/galeon/Advanced/Network/cache_compare"
#define CONF_NETWORK_USER_AGENT "/apps/galeon/Advanced/Network/user_agent"
#define CONF_NETWORK_HTTP_VERSION "/apps/galeon/Advanced/Network/http_version"

#define CONF_RENDERING_FONT "/apps/galeon/Rendering/font"
#define CONF_RENDERING_FONT_VAR_SIZE "/apps/galeon/Rendering/font_variable_size"
#define CONF_RENDERING_FONT_FIXED_SIZE "/apps/galeon/Rendering/font_monospace_size"
#define CONF_RENDERING_FONT_MIN_SIZE "/apps/galeon/Rendering/font_minimum_size"

#define CONF_RENDERING_LANGUAGE "/apps/galeon/Rendering/Language/lang"
#define CONF_RENDERING_USE_OWN_COLORS "/apps/galeon/Rendering/FontsColors/use_own_colors"
#define CONF_RENDERING_USE_SYSTEM_COLORS "/apps/galeon/Rendering/FontsColors/use_system_colors"
#define CONF_RENDERING_USE_OWN_FONTS "/apps/galeon/Rendering/FontsColors/use_own_fonts"
#define CONF_RENDERING_BG_COLOR "/apps/galeon/Rendering/FontsColors/background_color"
#define CONF_RENDERING_TEXT_COLOR "/apps/galeon/Rendering/FontsColors/text_color"
#define CONF_RENDERING_VISITED_LINKS "/apps/galeon/Rendering/FontsColors/visited_link_color"
#define CONF_RENDERING_UNVISITED_LINKS "/apps/galeon/Rendering/FontsColors/unvisited_link_color"
#define CONF_RENDERING_UNDERLINE_LINKS "/apps/galeon/Rendering/FontsColors/underline_links"
#define CONF_FILTERING_ALLOW_POPUPS "/apps/galeon/Advanced/Filtering/allow_popups"
#define CONF_FILTERING_ALLOW_CONTEXTMENU "/apps/galeon/Advanced/Filtering/allow_contextmenu_override"
#define CONF_FILTERING_IMAGE_LOADING_TYPE "/apps/galeon/Advanced/Filtering/image_loading_type"
#define CONF_FILTERING_ANIMATE_TYPE "/apps/galeon/Advanced/Filtering/animate_type"
#define CONF_FILTERING_JAVA_ENABLED "/apps/galeon/Advanced/Filtering/java_enabled"
#define CONF_FILTERING_JAVASCRIPT_ENABLED "/apps/galeon/Advanced/Filtering/javascript_enabled"
#define CONF_PERSISTENT_COOKIES_BEHAVIOR "/apps/galeon/Advanced/Persistent/cookie_behavior"
#define CONF_PERSISTENT_COOKIES_LIFETIME "/apps/galeon/Advanced/Persistent/cookies_lifetime"
#define CONF_PERSISTENT_COOKIE_ACCEPT_SESSION "/apps/galeon/Advanced/Persistent/cookie_accept_session"
#define CONF_PERSISTENT_PASSWORDS_SAVE "/apps/galeon/Advanced/Persistent/passwords_save"
#define CONF_LANGUAGE_AUTODETECT_CHARSET "/apps/galeon/Rendering/Language/autodetect_charset"
#define CONF_LANGUAGE_DEFAULT_CHARSET "/apps/galeon/Rendering/Language/default_charset"
#define CONF_RENDERING_DEFAULT_FONT "/apps/galeon/Rendering/FontsColors/default_font"
#define CONF_FILTERING_DEFAULT_STATUSBAR "/apps/galeon/Advanced/Filtering/default_allow_statusbar"

/* These are defined gnome wide now */
#define CONF_NETWORK_PROXY_MODE "/system/proxy/mode"
#define CONF_NETWORK_HTTP_PROXY "/system/http_proxy/host"
#define CONF_NETWORK_SSL_PROXY "/system/proxy/secure_host"
#define CONF_NETWORK_FTP_PROXY "/system/proxy/ftp_host"
#define CONF_NETWORK_SOCKS_PROXY "/system/proxy/socks_host"
#define CONF_NETWORK_HTTP_PROXY_PORT "/system/http_proxy/port"
#define CONF_NETWORK_SSL_PROXY_PORT "/system/proxy/secure_port"
#define CONF_NETWORK_FTP_PROXY_PORT "/system/proxy/ftp_port"
#define CONF_NETWORK_SOCKS_PROXY_PORT "/system/proxy/socks_port"
#define CONF_NETWORK_PROXY_AUTO_URL "/system/proxy/autoconfig_url"
#define CONF_NETWORK_PROXY_IGNORE_HOSTS "/system/http_proxy/ignore_hosts"
